@@ -28,7 +28,7 @@ class Dataset(EntityBase):
     def get_entities_as_response(self, since=None, limit=None, start=None, history=True, deleted=True,
                                  accept="application/json", reverse=False, uncommitted=None,
                                  subset=None, expected_node_id=None,
-                                 method="GET"
+                                 method="GET", **kwargs
                                  ):
         """
         :param since: The opaque value that can be used to efficiently skip already seen entities.
@@ -95,13 +95,13 @@ class Dataset(EntityBase):
             raise AssertionError("Unsupported request-method '%s'!" % (method,))
 
         response = request_func(url, allowable_response_status_codes=[200], stream=True,
-                                params=params, headers=headers)
+                                params=params, headers=headers, **kwargs)
 
         return response
 
     def get_entities_as_stream(self, since=None, limit=None, start=None, history=True, deleted=True,
                                accept="application/json", reverse=False, uncommitted=None,
-                               subset=None, expected_node_id=None
+                               subset=None, expected_node_id=None, **kwargs
                                ):
         """This returns a http stream for getting the entities of this dataset. (The returned object is a file-like
         stream from the 'requests' library, i.e response.raw)
@@ -109,14 +109,14 @@ class Dataset(EntityBase):
         response = self.get_entities_as_response(since=since, limit=limit, start=start, history=history,
                                                  deleted=deleted, accept=accept, reverse=reverse,
                                                  uncommitted=uncommitted,
-                                                 subset=subset, expected_node_id=expected_node_id
+                                                 subset=subset, expected_node_id=expected_node_id, **kwargs
                                                  )
 
         return response.raw
 
     def get_entities(self, since=None, limit=None, start=None, history=True, deleted=True, reverse=False,
                      uncommitted=None,
-                     subset=None, expected_node_id=None
+                     subset=None, expected_node_id=None, **kwargs
                      ):
         """This returns a generator for iterating over the entities of this dataset.
 
@@ -125,11 +125,11 @@ class Dataset(EntityBase):
         """
         entities_stream = self.get_entities_as_stream(since=since, limit=limit, start=start, history=history,
                                                       deleted=deleted, reverse=reverse, uncommitted=uncommitted,
-                                                      subset=subset, expected_node_id=expected_node_id
+                                                      subset=subset, expected_node_id=expected_node_id, **kwargs
                                                       )
         return entity_json.parse_json_stream(entities_stream)
 
-    def get_entity(self, entity_id, offset=None):
+    def get_entity(self, entity_id, offset=None, **kwargs):
         """Returns the specified entity if it exist, or None if the entity does not exist.
 
         :param entity_id:
@@ -140,13 +140,13 @@ class Dataset(EntityBase):
             params["offset"] = offset
         response = self._connection.do_get_request(url,
                                                    allowable_response_status_codes=[200, 404],
-                                                   params=params)
+                                                   params=params, **kwargs)
         if response.status_code == 404:
             # No such element.
             return None
         return entity_json.parse_entity(response.content.decode("utf-8"))
 
-    def post_entities(self, entities, force=None):
+    def post_entities(self, entities, force=None, **kwargs):
         """This posts the specified entities to the dataset."""
         url = self._connection.get_dataset_entities_url(self.id)
         params = {}
@@ -158,7 +158,7 @@ class Dataset(EntityBase):
                                                     allowable_response_status_codes=[200],
                                                     headers={"Content-Type": "application/json"},
                                                     data=entity_json.entities_to_json(entities),
-                                                    params=params)
+                                                    params=params, **kwargs)
         return response.json()
 
     @property
@@ -185,17 +185,17 @@ class Dataset(EntityBase):
     def num_deleted_entities_in_log(self):
         return self._raw_jsondata["runtime"]["count-index-deleted"]
 
-    def get_indexes(self):
+    def get_indexes(self, **kwargs):
         url = self._connection.get_dataset_indexes_url(self.id)
-        response = self._connection.do_get_request(url)
+        response = self._connection.do_get_request(url, **kwargs)
         indexes = response.json()
         return indexes
 
-    def wait_for_indexes_to_finish_updating(self, timeout=60, verbosity=0):
+    def wait_for_indexes_to_finish_updating(self, timeout=60, verbosity=0, **kwargs):
         starttime = time.monotonic()
         time_of_last_log_output = 0
         while True:
-            indexes = self.get_indexes()
+            indexes = self.get_indexes(**kwargs)
             for index in indexes:
                 if index["status"] not in ["up-to-date", "orphaned"]:
                     # at least one index is still being updated
@@ -224,17 +224,17 @@ class Dataset(EntityBase):
                         self.as_json(),))
             time.sleep(0.5)
 
-    def delete(self):
+    def delete(self, **kwargs):
         """Deletes this dataset from the sesam-node.
         """
         url = self._connection.get_dataset_url(self.id)
-        response = self._connection.do_delete_request(url, allowable_response_status_codes=[200])
+        response = self._connection.do_delete_request(url, allowable_response_status_codes=[200], **kwargs)
         self.update_raw_jsondata(response.content.decode("utf-8"))
 
     def run_operation(self,
                       operation,
                       operation_parameters=None,
-                      allowable_response_status_codes=frozenset([200])):
+                      allowable_response_status_codes=frozenset([200]), **kwargs):
         """Runs the specified operation on the dataset.
         :param operation: The operation to run.
         :param operation_parameters: A dict with operation parameters.
@@ -248,6 +248,6 @@ class Dataset(EntityBase):
 
         response = self._connection.do_post_request(url,
                                                     allowable_response_status_codes=allowable_response_status_codes,
-                                                    data=postdata)
+                                                    data=postdata, **kwargs)
 
         return response.json()
